# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetConsulServiceDiscoveryResult',
    'AwaitableGetConsulServiceDiscoveryResult',
    'get_consul_service_discovery',
    'get_consul_service_discovery_output',
]

@pulumi.output_type
class GetConsulServiceDiscoveryResult:
    """
    A collection of values returned by getConsulServiceDiscovery.
    """
    def __init__(__self__, address_realm=None, consul_sd_json=None, credential_update=None, encoded_token=None, id=None, jmes_path_query=None, minimum_monitors=None, port=None, reject_unauthorized=None, trust_ca=None, type=None, undetectable_action=None, update_interval=None, uri=None):
        if address_realm and not isinstance(address_realm, str):
            raise TypeError("Expected argument 'address_realm' to be a str")
        pulumi.set(__self__, "address_realm", address_realm)
        if consul_sd_json and not isinstance(consul_sd_json, str):
            raise TypeError("Expected argument 'consul_sd_json' to be a str")
        pulumi.set(__self__, "consul_sd_json", consul_sd_json)
        if credential_update and not isinstance(credential_update, bool):
            raise TypeError("Expected argument 'credential_update' to be a bool")
        pulumi.set(__self__, "credential_update", credential_update)
        if encoded_token and not isinstance(encoded_token, str):
            raise TypeError("Expected argument 'encoded_token' to be a str")
        pulumi.set(__self__, "encoded_token", encoded_token)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if jmes_path_query and not isinstance(jmes_path_query, str):
            raise TypeError("Expected argument 'jmes_path_query' to be a str")
        pulumi.set(__self__, "jmes_path_query", jmes_path_query)
        if minimum_monitors and not isinstance(minimum_monitors, str):
            raise TypeError("Expected argument 'minimum_monitors' to be a str")
        pulumi.set(__self__, "minimum_monitors", minimum_monitors)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if reject_unauthorized and not isinstance(reject_unauthorized, bool):
            raise TypeError("Expected argument 'reject_unauthorized' to be a bool")
        pulumi.set(__self__, "reject_unauthorized", reject_unauthorized)
        if trust_ca and not isinstance(trust_ca, str):
            raise TypeError("Expected argument 'trust_ca' to be a str")
        pulumi.set(__self__, "trust_ca", trust_ca)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if undetectable_action and not isinstance(undetectable_action, str):
            raise TypeError("Expected argument 'undetectable_action' to be a str")
        pulumi.set(__self__, "undetectable_action", undetectable_action)
        if update_interval and not isinstance(update_interval, str):
            raise TypeError("Expected argument 'update_interval' to be a str")
        pulumi.set(__self__, "update_interval", update_interval)
        if uri and not isinstance(uri, str):
            raise TypeError("Expected argument 'uri' to be a str")
        pulumi.set(__self__, "uri", uri)

    @_builtins.property
    @pulumi.getter(name="addressRealm")
    def address_realm(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "address_realm")

    @_builtins.property
    @pulumi.getter(name="consulSdJson")
    def consul_sd_json(self) -> _builtins.str:
        return pulumi.get(self, "consul_sd_json")

    @_builtins.property
    @pulumi.getter(name="credentialUpdate")
    def credential_update(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "credential_update")

    @_builtins.property
    @pulumi.getter(name="encodedToken")
    def encoded_token(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "encoded_token")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="jmesPathQuery")
    def jmes_path_query(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "jmes_path_query")

    @_builtins.property
    @pulumi.getter(name="minimumMonitors")
    def minimum_monitors(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "minimum_monitors")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="rejectUnauthorized")
    def reject_unauthorized(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "reject_unauthorized")

    @_builtins.property
    @pulumi.getter(name="trustCa")
    def trust_ca(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "trust_ca")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="undetectableAction")
    def undetectable_action(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "undetectable_action")

    @_builtins.property
    @pulumi.getter(name="updateInterval")
    def update_interval(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "update_interval")

    @_builtins.property
    @pulumi.getter
    def uri(self) -> _builtins.str:
        return pulumi.get(self, "uri")


class AwaitableGetConsulServiceDiscoveryResult(GetConsulServiceDiscoveryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConsulServiceDiscoveryResult(
            address_realm=self.address_realm,
            consul_sd_json=self.consul_sd_json,
            credential_update=self.credential_update,
            encoded_token=self.encoded_token,
            id=self.id,
            jmes_path_query=self.jmes_path_query,
            minimum_monitors=self.minimum_monitors,
            port=self.port,
            reject_unauthorized=self.reject_unauthorized,
            trust_ca=self.trust_ca,
            type=self.type,
            undetectable_action=self.undetectable_action,
            update_interval=self.update_interval,
            uri=self.uri)


def get_consul_service_discovery(address_realm: Optional[_builtins.str] = None,
                                 credential_update: Optional[_builtins.bool] = None,
                                 encoded_token: Optional[_builtins.str] = None,
                                 jmes_path_query: Optional[_builtins.str] = None,
                                 minimum_monitors: Optional[_builtins.str] = None,
                                 port: Optional[_builtins.int] = None,
                                 reject_unauthorized: Optional[_builtins.bool] = None,
                                 trust_ca: Optional[_builtins.str] = None,
                                 type: Optional[_builtins.str] = None,
                                 undetectable_action: Optional[_builtins.str] = None,
                                 update_interval: Optional[_builtins.str] = None,
                                 uri: Optional[_builtins.str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConsulServiceDiscoveryResult:
    """
    Use this data source (`fast_get_consul_service_discovery`) to get the Consul Service discovery config to be used for `http`/`https` app deployment in FAST.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    tc2 = f5bigip.fast.get_consul_service_discovery(uri="https://192.0.2.100:8500/v1/catalog/nodes",
        port=8080)
    ```


    :param _builtins.str address_realm: Specifies whether to look for public or private IP addresses,default `private`.
    :param _builtins.bool credential_update: Specifies whether you are updating your credentials,default `false`.
    :param _builtins.str encoded_token: Base 64 encoded bearer token to make requests to the Consul API. Will be stored in the declaration in an encrypted format.
    :param _builtins.str jmes_path_query: Custom JMESPath Query.
    :param _builtins.str minimum_monitors: Member is down when fewer than minimum monitors report it healthy.
    :param _builtins.int port: Port to be used for AWS service discovery,default `80`.
    :param _builtins.bool reject_unauthorized: If true, the server certificate is verified against the list of supplied/default CAs when making requests to the Consul API.
    :param _builtins.str trust_ca: CA Bundle to validate server certificates.
    :param _builtins.str undetectable_action: Action to take when node cannot be detected,default `remove`.
    :param _builtins.str update_interval: Update interval for service discovery.
    :param _builtins.str uri: The location of the node data.
    """
    __args__ = dict()
    __args__['addressRealm'] = address_realm
    __args__['credentialUpdate'] = credential_update
    __args__['encodedToken'] = encoded_token
    __args__['jmesPathQuery'] = jmes_path_query
    __args__['minimumMonitors'] = minimum_monitors
    __args__['port'] = port
    __args__['rejectUnauthorized'] = reject_unauthorized
    __args__['trustCa'] = trust_ca
    __args__['type'] = type
    __args__['undetectableAction'] = undetectable_action
    __args__['updateInterval'] = update_interval
    __args__['uri'] = uri
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:fast/getConsulServiceDiscovery:getConsulServiceDiscovery', __args__, opts=opts, typ=GetConsulServiceDiscoveryResult).value

    return AwaitableGetConsulServiceDiscoveryResult(
        address_realm=pulumi.get(__ret__, 'address_realm'),
        consul_sd_json=pulumi.get(__ret__, 'consul_sd_json'),
        credential_update=pulumi.get(__ret__, 'credential_update'),
        encoded_token=pulumi.get(__ret__, 'encoded_token'),
        id=pulumi.get(__ret__, 'id'),
        jmes_path_query=pulumi.get(__ret__, 'jmes_path_query'),
        minimum_monitors=pulumi.get(__ret__, 'minimum_monitors'),
        port=pulumi.get(__ret__, 'port'),
        reject_unauthorized=pulumi.get(__ret__, 'reject_unauthorized'),
        trust_ca=pulumi.get(__ret__, 'trust_ca'),
        type=pulumi.get(__ret__, 'type'),
        undetectable_action=pulumi.get(__ret__, 'undetectable_action'),
        update_interval=pulumi.get(__ret__, 'update_interval'),
        uri=pulumi.get(__ret__, 'uri'))
def get_consul_service_discovery_output(address_realm: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        credential_update: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                        encoded_token: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        jmes_path_query: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        minimum_monitors: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        port: Optional[pulumi.Input[_builtins.int]] = None,
                                        reject_unauthorized: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                        trust_ca: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        undetectable_action: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        update_interval: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        uri: Optional[pulumi.Input[_builtins.str]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetConsulServiceDiscoveryResult]:
    """
    Use this data source (`fast_get_consul_service_discovery`) to get the Consul Service discovery config to be used for `http`/`https` app deployment in FAST.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    tc2 = f5bigip.fast.get_consul_service_discovery(uri="https://192.0.2.100:8500/v1/catalog/nodes",
        port=8080)
    ```


    :param _builtins.str address_realm: Specifies whether to look for public or private IP addresses,default `private`.
    :param _builtins.bool credential_update: Specifies whether you are updating your credentials,default `false`.
    :param _builtins.str encoded_token: Base 64 encoded bearer token to make requests to the Consul API. Will be stored in the declaration in an encrypted format.
    :param _builtins.str jmes_path_query: Custom JMESPath Query.
    :param _builtins.str minimum_monitors: Member is down when fewer than minimum monitors report it healthy.
    :param _builtins.int port: Port to be used for AWS service discovery,default `80`.
    :param _builtins.bool reject_unauthorized: If true, the server certificate is verified against the list of supplied/default CAs when making requests to the Consul API.
    :param _builtins.str trust_ca: CA Bundle to validate server certificates.
    :param _builtins.str undetectable_action: Action to take when node cannot be detected,default `remove`.
    :param _builtins.str update_interval: Update interval for service discovery.
    :param _builtins.str uri: The location of the node data.
    """
    __args__ = dict()
    __args__['addressRealm'] = address_realm
    __args__['credentialUpdate'] = credential_update
    __args__['encodedToken'] = encoded_token
    __args__['jmesPathQuery'] = jmes_path_query
    __args__['minimumMonitors'] = minimum_monitors
    __args__['port'] = port
    __args__['rejectUnauthorized'] = reject_unauthorized
    __args__['trustCa'] = trust_ca
    __args__['type'] = type
    __args__['undetectableAction'] = undetectable_action
    __args__['updateInterval'] = update_interval
    __args__['uri'] = uri
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('f5bigip:fast/getConsulServiceDiscovery:getConsulServiceDiscovery', __args__, opts=opts, typ=GetConsulServiceDiscoveryResult)
    return __ret__.apply(lambda __response__: GetConsulServiceDiscoveryResult(
        address_realm=pulumi.get(__response__, 'address_realm'),
        consul_sd_json=pulumi.get(__response__, 'consul_sd_json'),
        credential_update=pulumi.get(__response__, 'credential_update'),
        encoded_token=pulumi.get(__response__, 'encoded_token'),
        id=pulumi.get(__response__, 'id'),
        jmes_path_query=pulumi.get(__response__, 'jmes_path_query'),
        minimum_monitors=pulumi.get(__response__, 'minimum_monitors'),
        port=pulumi.get(__response__, 'port'),
        reject_unauthorized=pulumi.get(__response__, 'reject_unauthorized'),
        trust_ca=pulumi.get(__response__, 'trust_ca'),
        type=pulumi.get(__response__, 'type'),
        undetectable_action=pulumi.get(__response__, 'undetectable_action'),
        update_interval=pulumi.get(__response__, 'update_interval'),
        uri=pulumi.get(__response__, 'uri')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetVWanConfigResult',
    'AwaitableGetVWanConfigResult',
    'get_v_wan_config',
    'get_v_wan_config_output',
]

@pulumi.output_type
class GetVWanConfigResult:
    """
    A collection of values returned by getVWanConfig.
    """
    def __init__(__self__, azure_vwan_name=None, azure_vwan_resourcegroup=None, azure_vwan_vpnsite=None, bigip_gw_ip=None, hub_address_space=None, hub_connected_subnets=None, id=None, preshared_key=None, vwan_gw_addresses=None):
        if azure_vwan_name and not isinstance(azure_vwan_name, str):
            raise TypeError("Expected argument 'azure_vwan_name' to be a str")
        pulumi.set(__self__, "azure_vwan_name", azure_vwan_name)
        if azure_vwan_resourcegroup and not isinstance(azure_vwan_resourcegroup, str):
            raise TypeError("Expected argument 'azure_vwan_resourcegroup' to be a str")
        pulumi.set(__self__, "azure_vwan_resourcegroup", azure_vwan_resourcegroup)
        if azure_vwan_vpnsite and not isinstance(azure_vwan_vpnsite, str):
            raise TypeError("Expected argument 'azure_vwan_vpnsite' to be a str")
        pulumi.set(__self__, "azure_vwan_vpnsite", azure_vwan_vpnsite)
        if bigip_gw_ip and not isinstance(bigip_gw_ip, str):
            raise TypeError("Expected argument 'bigip_gw_ip' to be a str")
        pulumi.set(__self__, "bigip_gw_ip", bigip_gw_ip)
        if hub_address_space and not isinstance(hub_address_space, str):
            raise TypeError("Expected argument 'hub_address_space' to be a str")
        pulumi.set(__self__, "hub_address_space", hub_address_space)
        if hub_connected_subnets and not isinstance(hub_connected_subnets, list):
            raise TypeError("Expected argument 'hub_connected_subnets' to be a list")
        pulumi.set(__self__, "hub_connected_subnets", hub_connected_subnets)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if preshared_key and not isinstance(preshared_key, str):
            raise TypeError("Expected argument 'preshared_key' to be a str")
        pulumi.set(__self__, "preshared_key", preshared_key)
        if vwan_gw_addresses and not isinstance(vwan_gw_addresses, list):
            raise TypeError("Expected argument 'vwan_gw_addresses' to be a list")
        pulumi.set(__self__, "vwan_gw_addresses", vwan_gw_addresses)

    @_builtins.property
    @pulumi.getter(name="azureVwanName")
    def azure_vwan_name(self) -> _builtins.str:
        return pulumi.get(self, "azure_vwan_name")

    @_builtins.property
    @pulumi.getter(name="azureVwanResourcegroup")
    def azure_vwan_resourcegroup(self) -> _builtins.str:
        return pulumi.get(self, "azure_vwan_resourcegroup")

    @_builtins.property
    @pulumi.getter(name="azureVwanVpnsite")
    def azure_vwan_vpnsite(self) -> _builtins.str:
        return pulumi.get(self, "azure_vwan_vpnsite")

    @_builtins.property
    @pulumi.getter(name="bigipGwIp")
    def bigip_gw_ip(self) -> _builtins.str:
        """
        (type `string`) provides IP address of BIGIP G/W for IPSec Endpoint.
        """
        return pulumi.get(self, "bigip_gw_ip")

    @_builtins.property
    @pulumi.getter(name="hubAddressSpace")
    def hub_address_space(self) -> _builtins.str:
        """
        (type `string`) Provides IP Address space used on vWAN Hub.
        """
        return pulumi.get(self, "hub_address_space")

    @_builtins.property
    @pulumi.getter(name="hubConnectedSubnets")
    def hub_connected_subnets(self) -> Sequence[_builtins.str]:
        """
        (type `list`) Provides Subnets connected to vWAN Hub.
        """
        return pulumi.get(self, "hub_connected_subnets")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="presharedKey")
    def preshared_key(self) -> _builtins.str:
        """
        (type `string`) provides pre-shared-key used for IPSec Tunnel creation.
        """
        return pulumi.get(self, "preshared_key")

    @_builtins.property
    @pulumi.getter(name="vwanGwAddresses")
    def vwan_gw_addresses(self) -> Sequence[_builtins.str]:
        """
        (type `list`) Provides vWAN Gateway Address for IPSec End point
        """
        return pulumi.get(self, "vwan_gw_addresses")


class AwaitableGetVWanConfigResult(GetVWanConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVWanConfigResult(
            azure_vwan_name=self.azure_vwan_name,
            azure_vwan_resourcegroup=self.azure_vwan_resourcegroup,
            azure_vwan_vpnsite=self.azure_vwan_vpnsite,
            bigip_gw_ip=self.bigip_gw_ip,
            hub_address_space=self.hub_address_space,
            hub_connected_subnets=self.hub_connected_subnets,
            id=self.id,
            preshared_key=self.preshared_key,
            vwan_gw_addresses=self.vwan_gw_addresses)


def get_v_wan_config(azure_vwan_name: Optional[_builtins.str] = None,
                     azure_vwan_resourcegroup: Optional[_builtins.str] = None,
                     azure_vwan_vpnsite: Optional[_builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVWanConfigResult:
    """
    Use this data source (`ssl_get_v_wan_config`) to get the vWAN site config from Azure VWAN Site

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    vwanconfig = f5bigip.ssl.get_v_wan_config(azure_vwan_resourcegroup="azurevwan-bigip-rg-9c8d",
        azure_vwan_name="azurevwan-bigip-vwan-9c8d",
        azure_vwan_vpnsite="azurevwan-bigip-vsite-9c8d")
    ```

    ## Pre-required Environment Settings:

    * `AZURE_CLIENT_ID` - (Required) Set this environment variable with the Azure app client ID to use.

    * `AZURE_CLIENT_SECRET` - (Required) Set this environment variable with the Azure app secret to use.

    * `AZURE_SUBSCRIPTION_ID` - (Required) Set this environment variable with the Azure subscription ID to use.

    * `AZURE_TENANT_ID` - (Required) Set this environment variable with the Tenant ID to which to authenticate.

    * `STORAGE_ACCOUNT_NAME` - (Required) Set this environment variable with the storage account for download config.

    * `STORAGE_ACCOUNT_KEY` - (Required) Specifies the storage account key to authenticate,set this Environment variable with account key value.


    :param _builtins.str azure_vwan_name: Name of the Azure vWAN Name
    :param _builtins.str azure_vwan_resourcegroup: Name of the Azure vWAN resource group
    :param _builtins.str azure_vwan_vpnsite: Name of the Azure vWAN VPN site from which configuration to be download
    """
    __args__ = dict()
    __args__['azureVwanName'] = azure_vwan_name
    __args__['azureVwanResourcegroup'] = azure_vwan_resourcegroup
    __args__['azureVwanVpnsite'] = azure_vwan_vpnsite
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:ssl/getVWanConfig:getVWanConfig', __args__, opts=opts, typ=GetVWanConfigResult).value

    return AwaitableGetVWanConfigResult(
        azure_vwan_name=pulumi.get(__ret__, 'azure_vwan_name'),
        azure_vwan_resourcegroup=pulumi.get(__ret__, 'azure_vwan_resourcegroup'),
        azure_vwan_vpnsite=pulumi.get(__ret__, 'azure_vwan_vpnsite'),
        bigip_gw_ip=pulumi.get(__ret__, 'bigip_gw_ip'),
        hub_address_space=pulumi.get(__ret__, 'hub_address_space'),
        hub_connected_subnets=pulumi.get(__ret__, 'hub_connected_subnets'),
        id=pulumi.get(__ret__, 'id'),
        preshared_key=pulumi.get(__ret__, 'preshared_key'),
        vwan_gw_addresses=pulumi.get(__ret__, 'vwan_gw_addresses'))
def get_v_wan_config_output(azure_vwan_name: Optional[pulumi.Input[_builtins.str]] = None,
                            azure_vwan_resourcegroup: Optional[pulumi.Input[_builtins.str]] = None,
                            azure_vwan_vpnsite: Optional[pulumi.Input[_builtins.str]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVWanConfigResult]:
    """
    Use this data source (`ssl_get_v_wan_config`) to get the vWAN site config from Azure VWAN Site

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    vwanconfig = f5bigip.ssl.get_v_wan_config(azure_vwan_resourcegroup="azurevwan-bigip-rg-9c8d",
        azure_vwan_name="azurevwan-bigip-vwan-9c8d",
        azure_vwan_vpnsite="azurevwan-bigip-vsite-9c8d")
    ```

    ## Pre-required Environment Settings:

    * `AZURE_CLIENT_ID` - (Required) Set this environment variable with the Azure app client ID to use.

    * `AZURE_CLIENT_SECRET` - (Required) Set this environment variable with the Azure app secret to use.

    * `AZURE_SUBSCRIPTION_ID` - (Required) Set this environment variable with the Azure subscription ID to use.

    * `AZURE_TENANT_ID` - (Required) Set this environment variable with the Tenant ID to which to authenticate.

    * `STORAGE_ACCOUNT_NAME` - (Required) Set this environment variable with the storage account for download config.

    * `STORAGE_ACCOUNT_KEY` - (Required) Specifies the storage account key to authenticate,set this Environment variable with account key value.


    :param _builtins.str azure_vwan_name: Name of the Azure vWAN Name
    :param _builtins.str azure_vwan_resourcegroup: Name of the Azure vWAN resource group
    :param _builtins.str azure_vwan_vpnsite: Name of the Azure vWAN VPN site from which configuration to be download
    """
    __args__ = dict()
    __args__['azureVwanName'] = azure_vwan_name
    __args__['azureVwanResourcegroup'] = azure_vwan_resourcegroup
    __args__['azureVwanVpnsite'] = azure_vwan_vpnsite
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('f5bigip:ssl/getVWanConfig:getVWanConfig', __args__, opts=opts, typ=GetVWanConfigResult)
    return __ret__.apply(lambda __response__: GetVWanConfigResult(
        azure_vwan_name=pulumi.get(__response__, 'azure_vwan_name'),
        azure_vwan_resourcegroup=pulumi.get(__response__, 'azure_vwan_resourcegroup'),
        azure_vwan_vpnsite=pulumi.get(__response__, 'azure_vwan_vpnsite'),
        bigip_gw_ip=pulumi.get(__response__, 'bigip_gw_ip'),
        hub_address_space=pulumi.get(__response__, 'hub_address_space'),
        hub_connected_subnets=pulumi.get(__response__, 'hub_connected_subnets'),
        id=pulumi.get(__response__, 'id'),
        preshared_key=pulumi.get(__response__, 'preshared_key'),
        vwan_gw_addresses=pulumi.get(__response__, 'vwan_gw_addresses')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['IpsecProfileArgs', 'IpsecProfile']

@pulumi.input_type
class IpsecProfileArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 traffic_selector: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a IpsecProfile resource.
        :param pulumi.Input[_builtins.str] name: Displays the name of the IPsec interface tunnel profile,it should be "full path".The full path is the combination of the partition + name of the IPSec profile.(For example `/Common/test-profile`)
        :param pulumi.Input[_builtins.str] description: Specifies descriptive text that identifies the IPsec interface tunnel profile.
        :param pulumi.Input[_builtins.str] parent_profile: Specifies the profile from which this profile inherits settings. The default is the system-supplied `/Common/ipsec` profile
        :param pulumi.Input[_builtins.str] traffic_selector: Specifies the traffic selector for the IPsec interface tunnel to which the profile is applied
        """
        pulumi.set(__self__, "name", name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if parent_profile is not None:
            pulumi.set(__self__, "parent_profile", parent_profile)
        if traffic_selector is not None:
            pulumi.set(__self__, "traffic_selector", traffic_selector)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Displays the name of the IPsec interface tunnel profile,it should be "full path".The full path is the combination of the partition + name of the IPSec profile.(For example `/Common/test-profile`)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies descriptive text that identifies the IPsec interface tunnel profile.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="parentProfile")
    def parent_profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the profile from which this profile inherits settings. The default is the system-supplied `/Common/ipsec` profile
        """
        return pulumi.get(self, "parent_profile")

    @parent_profile.setter
    def parent_profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_profile", value)

    @_builtins.property
    @pulumi.getter(name="trafficSelector")
    def traffic_selector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the traffic selector for the IPsec interface tunnel to which the profile is applied
        """
        return pulumi.get(self, "traffic_selector")

    @traffic_selector.setter
    def traffic_selector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "traffic_selector", value)


@pulumi.input_type
class _IpsecProfileState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 traffic_selector: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IpsecProfile resources.
        :param pulumi.Input[_builtins.str] description: Specifies descriptive text that identifies the IPsec interface tunnel profile.
        :param pulumi.Input[_builtins.str] name: Displays the name of the IPsec interface tunnel profile,it should be "full path".The full path is the combination of the partition + name of the IPSec profile.(For example `/Common/test-profile`)
        :param pulumi.Input[_builtins.str] parent_profile: Specifies the profile from which this profile inherits settings. The default is the system-supplied `/Common/ipsec` profile
        :param pulumi.Input[_builtins.str] traffic_selector: Specifies the traffic selector for the IPsec interface tunnel to which the profile is applied
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent_profile is not None:
            pulumi.set(__self__, "parent_profile", parent_profile)
        if traffic_selector is not None:
            pulumi.set(__self__, "traffic_selector", traffic_selector)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies descriptive text that identifies the IPsec interface tunnel profile.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Displays the name of the IPsec interface tunnel profile,it should be "full path".The full path is the combination of the partition + name of the IPSec profile.(For example `/Common/test-profile`)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="parentProfile")
    def parent_profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the profile from which this profile inherits settings. The default is the system-supplied `/Common/ipsec` profile
        """
        return pulumi.get(self, "parent_profile")

    @parent_profile.setter
    def parent_profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_profile", value)

    @_builtins.property
    @pulumi.getter(name="trafficSelector")
    def traffic_selector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the traffic selector for the IPsec interface tunnel to which the profile is applied
        """
        return pulumi.get(self, "traffic_selector")

    @traffic_selector.setter
    def traffic_selector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "traffic_selector", value)


@pulumi.type_token("f5bigip:index/ipsecProfile:IpsecProfile")
class IpsecProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 traffic_selector: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `IpsecProfile` Manage IPSec Profiles on a BIG-IP

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        azurev_wan_profile = f5bigip.IpsecProfile("azurevWAN_profile",
            name="/Common/Mytestipsecprofile",
            description="mytestipsecprofile",
            traffic_selector="test-trafficselector")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Specifies descriptive text that identifies the IPsec interface tunnel profile.
        :param pulumi.Input[_builtins.str] name: Displays the name of the IPsec interface tunnel profile,it should be "full path".The full path is the combination of the partition + name of the IPSec profile.(For example `/Common/test-profile`)
        :param pulumi.Input[_builtins.str] parent_profile: Specifies the profile from which this profile inherits settings. The default is the system-supplied `/Common/ipsec` profile
        :param pulumi.Input[_builtins.str] traffic_selector: Specifies the traffic selector for the IPsec interface tunnel to which the profile is applied
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpsecProfileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `IpsecProfile` Manage IPSec Profiles on a BIG-IP

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        azurev_wan_profile = f5bigip.IpsecProfile("azurevWAN_profile",
            name="/Common/Mytestipsecprofile",
            description="mytestipsecprofile",
            traffic_selector="test-trafficselector")
        ```

        :param str resource_name: The name of the resource.
        :param IpsecProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpsecProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 traffic_selector: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpsecProfileArgs.__new__(IpsecProfileArgs)

            __props__.__dict__["description"] = description
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["parent_profile"] = parent_profile
            __props__.__dict__["traffic_selector"] = traffic_selector
        super(IpsecProfile, __self__).__init__(
            'f5bigip:index/ipsecProfile:IpsecProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parent_profile: Optional[pulumi.Input[_builtins.str]] = None,
            traffic_selector: Optional[pulumi.Input[_builtins.str]] = None) -> 'IpsecProfile':
        """
        Get an existing IpsecProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Specifies descriptive text that identifies the IPsec interface tunnel profile.
        :param pulumi.Input[_builtins.str] name: Displays the name of the IPsec interface tunnel profile,it should be "full path".The full path is the combination of the partition + name of the IPSec profile.(For example `/Common/test-profile`)
        :param pulumi.Input[_builtins.str] parent_profile: Specifies the profile from which this profile inherits settings. The default is the system-supplied `/Common/ipsec` profile
        :param pulumi.Input[_builtins.str] traffic_selector: Specifies the traffic selector for the IPsec interface tunnel to which the profile is applied
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpsecProfileState.__new__(_IpsecProfileState)

        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["parent_profile"] = parent_profile
        __props__.__dict__["traffic_selector"] = traffic_selector
        return IpsecProfile(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies descriptive text that identifies the IPsec interface tunnel profile.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Displays the name of the IPsec interface tunnel profile,it should be "full path".The full path is the combination of the partition + name of the IPSec profile.(For example `/Common/test-profile`)
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="parentProfile")
    def parent_profile(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the profile from which this profile inherits settings. The default is the system-supplied `/Common/ipsec` profile
        """
        return pulumi.get(self, "parent_profile")

    @_builtins.property
    @pulumi.getter(name="trafficSelector")
    def traffic_selector(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the traffic selector for the IPsec interface tunnel to which the profile is applied
        """
        return pulumi.get(self, "traffic_selector")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'As3DeleteApps',
    'EventServiceDiscoveryNode',
    'FastHttpAppMonitor',
    'FastHttpAppPoolMember',
    'FastHttpAppVirtualServer',
    'FastHttpAppWafSecurityPolicy',
    'FastHttpsAppMonitor',
    'FastHttpsAppPoolMember',
    'FastHttpsAppTlsClientProfile',
    'FastHttpsAppTlsServerProfile',
    'FastHttpsAppVirtualServer',
    'FastHttpsAppWafSecurityPolicy',
    'FastTcpAppMonitor',
    'FastTcpAppPoolMember',
    'FastTcpAppVirtualServer',
    'FastUdpAppMonitor',
    'FastUdpAppPoolMember',
    'FastUdpAppVirtualServer',
    'SaasBotDefenseProfileProtectedEndpoint',
    'WafPolicyFileType',
    'WafPolicyGraphqlProfile',
    'WafPolicyGraphqlProfileDefenseAttribute',
    'WafPolicyHostName',
    'WafPolicyIpException',
    'WafPolicyPolicyBuilder',
    'WafPolicySignaturesSetting',
]

@pulumi.output_type
class As3DeleteApps(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "tenantName":
            suggest = "tenant_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in As3DeleteApps. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        As3DeleteApps.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        As3DeleteApps.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 apps: Sequence[_builtins.str],
                 tenant_name: _builtins.str):
        """
        :param Sequence[_builtins.str] apps: List of application names to delete from the specified tenant.
               
               > `delete_apps` cannot be used together with `as3_json`.
        :param _builtins.str tenant_name: Name of the tenant containing the apps to delete.
        """
        pulumi.set(__self__, "apps", apps)
        pulumi.set(__self__, "tenant_name", tenant_name)

    @_builtins.property
    @pulumi.getter
    def apps(self) -> Sequence[_builtins.str]:
        """
        List of application names to delete from the specified tenant.

        > `delete_apps` cannot be used together with `as3_json`.
        """
        return pulumi.get(self, "apps")

    @_builtins.property
    @pulumi.getter(name="tenantName")
    def tenant_name(self) -> _builtins.str:
        """
        Name of the tenant containing the apps to delete.
        """
        return pulumi.get(self, "tenant_name")


@pulumi.output_type
class EventServiceDiscoveryNode(dict):
    def __init__(__self__, *,
                 id: Optional[_builtins.str] = None,
                 ip: Optional[_builtins.str] = None,
                 port: Optional[_builtins.int] = None):
        """
        :param _builtins.str id: name of node
        :param _builtins.str ip: ip of nonde
        :param _builtins.int port: port
        """
        if id is not None:
            pulumi.set(__self__, "id", id)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        name of node
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[_builtins.str]:
        """
        ip of nonde
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        port
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class FastHttpAppMonitor(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "monitorAuth":
            suggest = "monitor_auth"
        elif key == "sendString":
            suggest = "send_string"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FastHttpAppMonitor. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FastHttpAppMonitor.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FastHttpAppMonitor.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 interval: Optional[_builtins.int] = None,
                 monitor_auth: Optional[_builtins.bool] = None,
                 password: Optional[_builtins.str] = None,
                 response: Optional[_builtins.str] = None,
                 send_string: Optional[_builtins.str] = None,
                 username: Optional[_builtins.str] = None):
        """
        :param _builtins.int interval: Set the time between health checks,in seconds for FAST-Generated Pool Monitor.
        :param _builtins.bool monitor_auth: set `true` if the servers require login credentials for web access on FAST-Generated Pool Monitor. default is `false`.
        :param _builtins.str password: password for web access on FAST-Generated Pool Monitor.
        :param _builtins.str response: The presence of this string anywhere in the HTTP response implies availability.
        :param _builtins.str send_string: Specify data to be sent during each health check for FAST-Generated Pool Monitor.
        :param _builtins.str username: username for web access on FAST-Generated Pool Monitor.
        """
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if monitor_auth is not None:
            pulumi.set(__self__, "monitor_auth", monitor_auth)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if response is not None:
            pulumi.set(__self__, "response", response)
        if send_string is not None:
            pulumi.set(__self__, "send_string", send_string)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def interval(self) -> Optional[_builtins.int]:
        """
        Set the time between health checks,in seconds for FAST-Generated Pool Monitor.
        """
        return pulumi.get(self, "interval")

    @_builtins.property
    @pulumi.getter(name="monitorAuth")
    def monitor_auth(self) -> Optional[_builtins.bool]:
        """
        set `true` if the servers require login credentials for web access on FAST-Generated Pool Monitor. default is `false`.
        """
        return pulumi.get(self, "monitor_auth")

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[_builtins.str]:
        """
        password for web access on FAST-Generated Pool Monitor.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def response(self) -> Optional[_builtins.str]:
        """
        The presence of this string anywhere in the HTTP response implies availability.
        """
        return pulumi.get(self, "response")

    @_builtins.property
    @pulumi.getter(name="sendString")
    def send_string(self) -> Optional[_builtins.str]:
        """
        Specify data to be sent during each health check for FAST-Generated Pool Monitor.
        """
        return pulumi.get(self, "send_string")

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[_builtins.str]:
        """
        username for web access on FAST-Generated Pool Monitor.
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class FastHttpAppPoolMember(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectionLimit":
            suggest = "connection_limit"
        elif key == "priorityGroup":
            suggest = "priority_group"
        elif key == "shareNodes":
            suggest = "share_nodes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FastHttpAppPoolMember. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FastHttpAppPoolMember.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FastHttpAppPoolMember.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 addresses: Sequence[_builtins.str],
                 connection_limit: Optional[_builtins.int] = None,
                 port: Optional[_builtins.int] = None,
                 priority_group: Optional[_builtins.int] = None,
                 share_nodes: Optional[_builtins.bool] = None):
        """
        :param Sequence[_builtins.str] addresses: List of server address to be used for FAST-Generated Pool.
        :param _builtins.int connection_limit: connectionLimit value to be used for FAST-Generated Pool.
        :param _builtins.int port: port number of serviceport to be used for FAST-Generated Pool.
        :param _builtins.int priority_group: priorityGroup value to be used for FAST-Generated Pool.
        :param _builtins.bool share_nodes: shareNodes value to be used for FAST-Generated Pool.
        """
        pulumi.set(__self__, "addresses", addresses)
        if connection_limit is not None:
            pulumi.set(__self__, "connection_limit", connection_limit)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority_group is not None:
            pulumi.set(__self__, "priority_group", priority_group)
        if share_nodes is not None:
            pulumi.set(__self__, "share_nodes", share_nodes)

    @_builtins.property
    @pulumi.getter
    def addresses(self) -> Sequence[_builtins.str]:
        """
        List of server address to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "addresses")

    @_builtins.property
    @pulumi.getter(name="connectionLimit")
    def connection_limit(self) -> Optional[_builtins.int]:
        """
        connectionLimit value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "connection_limit")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        port number of serviceport to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="priorityGroup")
    def priority_group(self) -> Optional[_builtins.int]:
        """
        priorityGroup value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "priority_group")

    @_builtins.property
    @pulumi.getter(name="shareNodes")
    def share_nodes(self) -> Optional[_builtins.bool]:
        """
        shareNodes value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "share_nodes")


@pulumi.output_type
class FastHttpAppVirtualServer(dict):
    def __init__(__self__, *,
                 ip: _builtins.str,
                 port: _builtins.int):
        """
        :param _builtins.str ip: IP4/IPv6 address to be used for virtual server ex: `10.1.1.1`
        :param _builtins.int port: Port number to used for accessing virtual server/application
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> _builtins.str:
        """
        IP4/IPv6 address to be used for virtual server ex: `10.1.1.1`
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Port number to used for accessing virtual server/application
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class FastHttpAppWafSecurityPolicy(dict):
    def __init__(__self__, *,
                 enable: _builtins.bool):
        """
        :param _builtins.bool enable: Setting `true` will enable FAST to create WAF Security Policy.
        """
        pulumi.set(__self__, "enable", enable)

    @_builtins.property
    @pulumi.getter
    def enable(self) -> _builtins.bool:
        """
        Setting `true` will enable FAST to create WAF Security Policy.
        """
        return pulumi.get(self, "enable")


@pulumi.output_type
class FastHttpsAppMonitor(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "monitorAuth":
            suggest = "monitor_auth"
        elif key == "sendString":
            suggest = "send_string"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FastHttpsAppMonitor. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FastHttpsAppMonitor.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FastHttpsAppMonitor.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 interval: Optional[_builtins.int] = None,
                 monitor_auth: Optional[_builtins.bool] = None,
                 password: Optional[_builtins.str] = None,
                 response: Optional[_builtins.str] = None,
                 send_string: Optional[_builtins.str] = None,
                 username: Optional[_builtins.str] = None):
        """
        :param _builtins.int interval: Set the time between health checks,in seconds for FAST-Generated Pool Monitor.
        :param _builtins.bool monitor_auth: set `true` if the servers require login credentials for web access on FAST-Generated Pool Monitor. default is `false`.
        :param _builtins.str password: password for web access on FAST-Generated Pool Monitor.
        :param _builtins.str response: The presence of this string anywhere in the HTTP response implies availability.
        :param _builtins.str send_string: Specify data to be sent during each health check for FAST-Generated Pool Monitor.
        :param _builtins.str username: username for web access on FAST-Generated Pool Monitor.
        """
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if monitor_auth is not None:
            pulumi.set(__self__, "monitor_auth", monitor_auth)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if response is not None:
            pulumi.set(__self__, "response", response)
        if send_string is not None:
            pulumi.set(__self__, "send_string", send_string)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def interval(self) -> Optional[_builtins.int]:
        """
        Set the time between health checks,in seconds for FAST-Generated Pool Monitor.
        """
        return pulumi.get(self, "interval")

    @_builtins.property
    @pulumi.getter(name="monitorAuth")
    def monitor_auth(self) -> Optional[_builtins.bool]:
        """
        set `true` if the servers require login credentials for web access on FAST-Generated Pool Monitor. default is `false`.
        """
        return pulumi.get(self, "monitor_auth")

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[_builtins.str]:
        """
        password for web access on FAST-Generated Pool Monitor.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def response(self) -> Optional[_builtins.str]:
        """
        The presence of this string anywhere in the HTTP response implies availability.
        """
        return pulumi.get(self, "response")

    @_builtins.property
    @pulumi.getter(name="sendString")
    def send_string(self) -> Optional[_builtins.str]:
        """
        Specify data to be sent during each health check for FAST-Generated Pool Monitor.
        """
        return pulumi.get(self, "send_string")

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[_builtins.str]:
        """
        username for web access on FAST-Generated Pool Monitor.
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class FastHttpsAppPoolMember(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectionLimit":
            suggest = "connection_limit"
        elif key == "priorityGroup":
            suggest = "priority_group"
        elif key == "shareNodes":
            suggest = "share_nodes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FastHttpsAppPoolMember. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FastHttpsAppPoolMember.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FastHttpsAppPoolMember.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 addresses: Sequence[_builtins.str],
                 connection_limit: Optional[_builtins.int] = None,
                 port: Optional[_builtins.int] = None,
                 priority_group: Optional[_builtins.int] = None,
                 share_nodes: Optional[_builtins.bool] = None):
        """
        :param Sequence[_builtins.str] addresses: List of server address to be used for FAST-Generated Pool.
        :param _builtins.int connection_limit: connectionLimit value to be used for FAST-Generated Pool.
        :param _builtins.int port: port number of serviceport to be used for FAST-Generated Pool.
        :param _builtins.int priority_group: priorityGroup value to be used for FAST-Generated Pool.
        :param _builtins.bool share_nodes: shareNodes value to be used for FAST-Generated Pool.
        """
        pulumi.set(__self__, "addresses", addresses)
        if connection_limit is not None:
            pulumi.set(__self__, "connection_limit", connection_limit)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority_group is not None:
            pulumi.set(__self__, "priority_group", priority_group)
        if share_nodes is not None:
            pulumi.set(__self__, "share_nodes", share_nodes)

    @_builtins.property
    @pulumi.getter
    def addresses(self) -> Sequence[_builtins.str]:
        """
        List of server address to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "addresses")

    @_builtins.property
    @pulumi.getter(name="connectionLimit")
    def connection_limit(self) -> Optional[_builtins.int]:
        """
        connectionLimit value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "connection_limit")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        port number of serviceport to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="priorityGroup")
    def priority_group(self) -> Optional[_builtins.int]:
        """
        priorityGroup value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "priority_group")

    @_builtins.property
    @pulumi.getter(name="shareNodes")
    def share_nodes(self) -> Optional[_builtins.bool]:
        """
        shareNodes value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "share_nodes")


@pulumi.output_type
class FastHttpsAppTlsClientProfile(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "tlsCertName":
            suggest = "tls_cert_name"
        elif key == "tlsKeyName":
            suggest = "tls_key_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FastHttpsAppTlsClientProfile. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FastHttpsAppTlsClientProfile.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FastHttpsAppTlsClientProfile.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 tls_cert_name: _builtins.str,
                 tls_key_name: _builtins.str):
        """
        :param _builtins.str tls_cert_name: Name of existing BIG-IP SSL certificate to be used for FAST-Generated TLS Server Profile.
        :param _builtins.str tls_key_name: Name of existing BIG-IP SSL Key to be used for FAST-Generated TLS Server Profile.
        """
        pulumi.set(__self__, "tls_cert_name", tls_cert_name)
        pulumi.set(__self__, "tls_key_name", tls_key_name)

    @_builtins.property
    @pulumi.getter(name="tlsCertName")
    def tls_cert_name(self) -> _builtins.str:
        """
        Name of existing BIG-IP SSL certificate to be used for FAST-Generated TLS Server Profile.
        """
        return pulumi.get(self, "tls_cert_name")

    @_builtins.property
    @pulumi.getter(name="tlsKeyName")
    def tls_key_name(self) -> _builtins.str:
        """
        Name of existing BIG-IP SSL Key to be used for FAST-Generated TLS Server Profile.
        """
        return pulumi.get(self, "tls_key_name")


@pulumi.output_type
class FastHttpsAppTlsServerProfile(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "tlsCertName":
            suggest = "tls_cert_name"
        elif key == "tlsKeyName":
            suggest = "tls_key_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FastHttpsAppTlsServerProfile. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FastHttpsAppTlsServerProfile.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FastHttpsAppTlsServerProfile.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 tls_cert_name: _builtins.str,
                 tls_key_name: _builtins.str):
        """
        :param _builtins.str tls_cert_name: Name of existing BIG-IP SSL certificate to be used for FAST-Generated TLS Server Profile.
        :param _builtins.str tls_key_name: Name of existing BIG-IP SSL Key to be used for FAST-Generated TLS Server Profile.
        """
        pulumi.set(__self__, "tls_cert_name", tls_cert_name)
        pulumi.set(__self__, "tls_key_name", tls_key_name)

    @_builtins.property
    @pulumi.getter(name="tlsCertName")
    def tls_cert_name(self) -> _builtins.str:
        """
        Name of existing BIG-IP SSL certificate to be used for FAST-Generated TLS Server Profile.
        """
        return pulumi.get(self, "tls_cert_name")

    @_builtins.property
    @pulumi.getter(name="tlsKeyName")
    def tls_key_name(self) -> _builtins.str:
        """
        Name of existing BIG-IP SSL Key to be used for FAST-Generated TLS Server Profile.
        """
        return pulumi.get(self, "tls_key_name")


@pulumi.output_type
class FastHttpsAppVirtualServer(dict):
    def __init__(__self__, *,
                 ip: _builtins.str,
                 port: _builtins.int):
        """
        :param _builtins.str ip: IP4/IPv6 address to be used for virtual server ex: `10.1.1.1`
        :param _builtins.int port: Port number to used for accessing virtual server/application
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> _builtins.str:
        """
        IP4/IPv6 address to be used for virtual server ex: `10.1.1.1`
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Port number to used for accessing virtual server/application
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class FastHttpsAppWafSecurityPolicy(dict):
    def __init__(__self__, *,
                 enable: _builtins.bool):
        """
        :param _builtins.bool enable: Setting `true` will enable FAST to create WAF Security Policy.
        """
        pulumi.set(__self__, "enable", enable)

    @_builtins.property
    @pulumi.getter
    def enable(self) -> _builtins.bool:
        """
        Setting `true` will enable FAST to create WAF Security Policy.
        """
        return pulumi.get(self, "enable")


@pulumi.output_type
class FastTcpAppMonitor(dict):
    def __init__(__self__, *,
                 interval: Optional[_builtins.int] = None):
        """
        :param _builtins.int interval: Set the time between health checks,in seconds for FAST-Generated Pool Monitor.
        """
        if interval is not None:
            pulumi.set(__self__, "interval", interval)

    @_builtins.property
    @pulumi.getter
    def interval(self) -> Optional[_builtins.int]:
        """
        Set the time between health checks,in seconds for FAST-Generated Pool Monitor.
        """
        return pulumi.get(self, "interval")


@pulumi.output_type
class FastTcpAppPoolMember(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectionLimit":
            suggest = "connection_limit"
        elif key == "priorityGroup":
            suggest = "priority_group"
        elif key == "shareNodes":
            suggest = "share_nodes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FastTcpAppPoolMember. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FastTcpAppPoolMember.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FastTcpAppPoolMember.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 addresses: Sequence[_builtins.str],
                 connection_limit: Optional[_builtins.int] = None,
                 port: Optional[_builtins.int] = None,
                 priority_group: Optional[_builtins.int] = None,
                 share_nodes: Optional[_builtins.bool] = None):
        """
        :param Sequence[_builtins.str] addresses: List of server address to be used for FAST-Generated Pool.
        :param _builtins.int connection_limit: connectionLimit value to be used for FAST-Generated Pool.
        :param _builtins.int port: port number of serviceport to be used for FAST-Generated Pool.
        :param _builtins.int priority_group: priorityGroup value to be used for FAST-Generated Pool.
        :param _builtins.bool share_nodes: shareNodes value to be used for FAST-Generated Pool.
        """
        pulumi.set(__self__, "addresses", addresses)
        if connection_limit is not None:
            pulumi.set(__self__, "connection_limit", connection_limit)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority_group is not None:
            pulumi.set(__self__, "priority_group", priority_group)
        if share_nodes is not None:
            pulumi.set(__self__, "share_nodes", share_nodes)

    @_builtins.property
    @pulumi.getter
    def addresses(self) -> Sequence[_builtins.str]:
        """
        List of server address to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "addresses")

    @_builtins.property
    @pulumi.getter(name="connectionLimit")
    def connection_limit(self) -> Optional[_builtins.int]:
        """
        connectionLimit value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "connection_limit")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        port number of serviceport to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="priorityGroup")
    def priority_group(self) -> Optional[_builtins.int]:
        """
        priorityGroup value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "priority_group")

    @_builtins.property
    @pulumi.getter(name="shareNodes")
    def share_nodes(self) -> Optional[_builtins.bool]:
        """
        shareNodes value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "share_nodes")


@pulumi.output_type
class FastTcpAppVirtualServer(dict):
    def __init__(__self__, *,
                 ip: _builtins.str,
                 port: _builtins.int):
        """
        :param _builtins.str ip: IP4/IPv6 address to be used for virtual server ex: `10.1.1.1`
        :param _builtins.int port: Port number to used for accessing virtual server/application
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> _builtins.str:
        """
        IP4/IPv6 address to be used for virtual server ex: `10.1.1.1`
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Port number to used for accessing virtual server/application
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class FastUdpAppMonitor(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expectedResponse":
            suggest = "expected_response"
        elif key == "sendString":
            suggest = "send_string"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FastUdpAppMonitor. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FastUdpAppMonitor.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FastUdpAppMonitor.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expected_response: Optional[_builtins.str] = None,
                 interval: Optional[_builtins.int] = None,
                 send_string: Optional[_builtins.str] = None):
        """
        :param _builtins.str expected_response: The presence of this optional string is required in the response, if specified it confirms availability.
        :param _builtins.int interval: Set the time between health checks,in seconds for FAST-Generated Pool Monitor.
        :param _builtins.str send_string: Optional data to be sent during each health check.
        """
        if expected_response is not None:
            pulumi.set(__self__, "expected_response", expected_response)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if send_string is not None:
            pulumi.set(__self__, "send_string", send_string)

    @_builtins.property
    @pulumi.getter(name="expectedResponse")
    def expected_response(self) -> Optional[_builtins.str]:
        """
        The presence of this optional string is required in the response, if specified it confirms availability.
        """
        return pulumi.get(self, "expected_response")

    @_builtins.property
    @pulumi.getter
    def interval(self) -> Optional[_builtins.int]:
        """
        Set the time between health checks,in seconds for FAST-Generated Pool Monitor.
        """
        return pulumi.get(self, "interval")

    @_builtins.property
    @pulumi.getter(name="sendString")
    def send_string(self) -> Optional[_builtins.str]:
        """
        Optional data to be sent during each health check.
        """
        return pulumi.get(self, "send_string")


@pulumi.output_type
class FastUdpAppPoolMember(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectionLimit":
            suggest = "connection_limit"
        elif key == "priorityGroup":
            suggest = "priority_group"
        elif key == "shareNodes":
            suggest = "share_nodes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FastUdpAppPoolMember. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FastUdpAppPoolMember.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FastUdpAppPoolMember.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 addresses: Sequence[_builtins.str],
                 connection_limit: Optional[_builtins.int] = None,
                 port: Optional[_builtins.int] = None,
                 priority_group: Optional[_builtins.int] = None,
                 share_nodes: Optional[_builtins.bool] = None):
        """
        :param Sequence[_builtins.str] addresses: List of server address to be used for FAST-Generated Pool.
        :param _builtins.int connection_limit: connectionLimit value to be used for FAST-Generated Pool.
        :param _builtins.int port: port number of serviceport to be used for FAST-Generated Pool.
        :param _builtins.int priority_group: priorityGroup value to be used for FAST-Generated Pool.
        :param _builtins.bool share_nodes: shareNodes value to be used for FAST-Generated Pool.
        """
        pulumi.set(__self__, "addresses", addresses)
        if connection_limit is not None:
            pulumi.set(__self__, "connection_limit", connection_limit)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority_group is not None:
            pulumi.set(__self__, "priority_group", priority_group)
        if share_nodes is not None:
            pulumi.set(__self__, "share_nodes", share_nodes)

    @_builtins.property
    @pulumi.getter
    def addresses(self) -> Sequence[_builtins.str]:
        """
        List of server address to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "addresses")

    @_builtins.property
    @pulumi.getter(name="connectionLimit")
    def connection_limit(self) -> Optional[_builtins.int]:
        """
        connectionLimit value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "connection_limit")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        port number of serviceport to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="priorityGroup")
    def priority_group(self) -> Optional[_builtins.int]:
        """
        priorityGroup value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "priority_group")

    @_builtins.property
    @pulumi.getter(name="shareNodes")
    def share_nodes(self) -> Optional[_builtins.bool]:
        """
        shareNodes value to be used for FAST-Generated Pool.
        """
        return pulumi.get(self, "share_nodes")


@pulumi.output_type
class FastUdpAppVirtualServer(dict):
    def __init__(__self__, *,
                 ip: _builtins.str,
                 port: _builtins.int):
        """
        :param _builtins.str ip: IP4/IPv6 address to be used for virtual server ex: `10.1.1.1`
        :param _builtins.int port: Port number to used for accessing virtual server/application
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> _builtins.str:
        """
        IP4/IPv6 address to be used for virtual server ex: `10.1.1.1`
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Port number to used for accessing virtual server/application
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class SaasBotDefenseProfileProtectedEndpoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "mitigationAction":
            suggest = "mitigation_action"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SaasBotDefenseProfileProtectedEndpoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SaasBotDefenseProfileProtectedEndpoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SaasBotDefenseProfileProtectedEndpoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: _builtins.str,
                 endpoint: Optional[_builtins.str] = None,
                 host: Optional[_builtins.str] = None,
                 mitigation_action: Optional[_builtins.str] = None,
                 post: Optional[_builtins.str] = None,
                 put: Optional[_builtins.str] = None):
        """
        :param _builtins.str name: Unique name for the protected endpoint
        :param _builtins.str endpoint: Specifies the path to the web page to be protected by BD. For example, `/login`.
        :param _builtins.str host: hostname or IP address of the web page to be protected by the Bot Defense
        :param _builtins.str mitigation_action: Specifies whether the BIG-IP or F5 XC Bot Defense handles mitigation of malicious HTTP requests. This field is enabled only if the Service Level field is set to Advanced/Premium
        :param _builtins.str post: POST field to protect the path when it has a POST method, `enabled` or `disabled`
        :param _builtins.str put: PUT field to protect the path when it has a PUT method,`enabled` or `disabled`
        """
        pulumi.set(__self__, "name", name)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if mitigation_action is not None:
            pulumi.set(__self__, "mitigation_action", mitigation_action)
        if post is not None:
            pulumi.set(__self__, "post", post)
        if put is not None:
            pulumi.set(__self__, "put", put)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Unique name for the protected endpoint
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> Optional[_builtins.str]:
        """
        Specifies the path to the web page to be protected by BD. For example, `/login`.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def host(self) -> Optional[_builtins.str]:
        """
        hostname or IP address of the web page to be protected by the Bot Defense
        """
        return pulumi.get(self, "host")

    @_builtins.property
    @pulumi.getter(name="mitigationAction")
    def mitigation_action(self) -> Optional[_builtins.str]:
        """
        Specifies whether the BIG-IP or F5 XC Bot Defense handles mitigation of malicious HTTP requests. This field is enabled only if the Service Level field is set to Advanced/Premium
        """
        return pulumi.get(self, "mitigation_action")

    @_builtins.property
    @pulumi.getter
    def post(self) -> Optional[_builtins.str]:
        """
        POST field to protect the path when it has a POST method, `enabled` or `disabled`
        """
        return pulumi.get(self, "post")

    @_builtins.property
    @pulumi.getter
    def put(self) -> Optional[_builtins.str]:
        """
        PUT field to protect the path when it has a PUT method,`enabled` or `disabled`
        """
        return pulumi.get(self, "put")


@pulumi.output_type
class WafPolicyFileType(dict):
    def __init__(__self__, *,
                 allowed: Optional[_builtins.bool] = None,
                 name: Optional[_builtins.str] = None,
                 type: Optional[_builtins.str] = None):
        """
        :param _builtins.bool allowed: Determines whether the file type is allowed or disallowed. In either of these cases the VIOL_FILETYPE violation is issued (if enabled) for an incoming request- 
               * No allowed file type matched the file type of the request.
               * The file type of the request matched a disallowed file type.
        :param _builtins.str name: Specifies the file type name as appearing in the URL extension.
        :param _builtins.str type: Determines the type of the name attribute. Only when setting the type to `wildcard` will the special wildcard characters in the name be interpreted as such
        """
        if allowed is not None:
            pulumi.set(__self__, "allowed", allowed)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def allowed(self) -> Optional[_builtins.bool]:
        """
        Determines whether the file type is allowed or disallowed. In either of these cases the VIOL_FILETYPE violation is issued (if enabled) for an incoming request- 
        * No allowed file type matched the file type of the request.
        * The file type of the request matched a disallowed file type.
        """
        return pulumi.get(self, "allowed")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Specifies the file type name as appearing in the URL extension.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        """
        Determines the type of the name attribute. Only when setting the type to `wildcard` will the special wildcard characters in the name be interpreted as such
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class WafPolicyGraphqlProfile(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "attackSignaturesCheck":
            suggest = "attack_signatures_check"
        elif key == "defenseAttributes":
            suggest = "defense_attributes"
        elif key == "metacharElementcheck":
            suggest = "metachar_elementcheck"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WafPolicyGraphqlProfile. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WafPolicyGraphqlProfile.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WafPolicyGraphqlProfile.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: _builtins.str,
                 attack_signatures_check: Optional[_builtins.bool] = None,
                 defense_attributes: Optional[Sequence['outputs.WafPolicyGraphqlProfileDefenseAttribute']] = None,
                 metachar_elementcheck: Optional[_builtins.bool] = None):
        """
        :param _builtins.str name: The unique user-given name of the policy. Policy names cannot contain spaces or special characters. Allowed characters are a-z, A-Z, 0-9, dot, dash (-), colon (:) and underscore (_).
        :param _builtins.bool attack_signatures_check: Specifies when checked (enabled) that you want attack signatures and threat campaigns to be detected on this GraphQL profile and possibly override the security policy settings of an attack signature or threat campaign specifically for this GraphQL profile. After you enable this setting, the system displays a list of attack signatures and and threat campaigns. The default is enabled
        :param Sequence['WafPolicyGraphqlProfileDefenseAttributeArgs'] defense_attributes: defense_attributes settings for policy
        :param _builtins.bool metachar_elementcheck: Specifies when checked (enabled) that the system enforces the security policy settings of a meta character for the GraphQL profile. After you enable this setting, the system displays a list of meta characters. The default is enabled
        """
        pulumi.set(__self__, "name", name)
        if attack_signatures_check is not None:
            pulumi.set(__self__, "attack_signatures_check", attack_signatures_check)
        if defense_attributes is not None:
            pulumi.set(__self__, "defense_attributes", defense_attributes)
        if metachar_elementcheck is not None:
            pulumi.set(__self__, "metachar_elementcheck", metachar_elementcheck)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The unique user-given name of the policy. Policy names cannot contain spaces or special characters. Allowed characters are a-z, A-Z, 0-9, dot, dash (-), colon (:) and underscore (_).
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="attackSignaturesCheck")
    def attack_signatures_check(self) -> Optional[_builtins.bool]:
        """
        Specifies when checked (enabled) that you want attack signatures and threat campaigns to be detected on this GraphQL profile and possibly override the security policy settings of an attack signature or threat campaign specifically for this GraphQL profile. After you enable this setting, the system displays a list of attack signatures and and threat campaigns. The default is enabled
        """
        return pulumi.get(self, "attack_signatures_check")

    @_builtins.property
    @pulumi.getter(name="defenseAttributes")
    def defense_attributes(self) -> Optional[Sequence['outputs.WafPolicyGraphqlProfileDefenseAttribute']]:
        """
        defense_attributes settings for policy
        """
        return pulumi.get(self, "defense_attributes")

    @_builtins.property
    @pulumi.getter(name="metacharElementcheck")
    def metachar_elementcheck(self) -> Optional[_builtins.bool]:
        """
        Specifies when checked (enabled) that the system enforces the security policy settings of a meta character for the GraphQL profile. After you enable this setting, the system displays a list of meta characters. The default is enabled
        """
        return pulumi.get(self, "metachar_elementcheck")


@pulumi.output_type
class WafPolicyGraphqlProfileDefenseAttribute(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allowIntrospectionQueries":
            suggest = "allow_introspection_queries"
        elif key == "maximumBatchedQueries":
            suggest = "maximum_batched_queries"
        elif key == "maximumStructureDepth":
            suggest = "maximum_structure_depth"
        elif key == "maximumTotalLength":
            suggest = "maximum_total_length"
        elif key == "maximumValueLength":
            suggest = "maximum_value_length"
        elif key == "tolerateParsingWarnings":
            suggest = "tolerate_parsing_warnings"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WafPolicyGraphqlProfileDefenseAttribute. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WafPolicyGraphqlProfileDefenseAttribute.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WafPolicyGraphqlProfileDefenseAttribute.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allow_introspection_queries: Optional[_builtins.bool] = None,
                 maximum_batched_queries: Optional[_builtins.str] = None,
                 maximum_structure_depth: Optional[_builtins.str] = None,
                 maximum_total_length: Optional[_builtins.str] = None,
                 maximum_value_length: Optional[_builtins.str] = None,
                 tolerate_parsing_warnings: Optional[_builtins.bool] = None):
        """
        :param _builtins.bool allow_introspection_queries: Introspection queries can also be enforced to prevent attackers from using them to
               understand the API structure and potentially breach an application.
        :param _builtins.str maximum_batched_queries: Specifies the highest number of batched queries allowed by the security policy.
        :param _builtins.str maximum_structure_depth: Specifies the greatest nesting depth found in the GraphQL structure allowed by the security policy.
        :param _builtins.str maximum_total_length: Specifies the longest length, in bytes, allowed by the security policy of the request payload, or parameter value, where the GraphQL data was found.
        :param _builtins.str maximum_value_length: Specifies the longest length (in bytes) of the longest GraphQL element value in the document allowed by the security policy.
        :param _builtins.bool tolerate_parsing_warnings: Specifies, when checked (enabled), that the system does not report when the security enforcer encounters warnings while parsing GraphQL content. Specifies when cleared (disabled), that the security policy reports when the security enforcer encounters warnings while parsing GraphQL content. The default setting is disabled.
        """
        if allow_introspection_queries is not None:
            pulumi.set(__self__, "allow_introspection_queries", allow_introspection_queries)
        if maximum_batched_queries is not None:
            pulumi.set(__self__, "maximum_batched_queries", maximum_batched_queries)
        if maximum_structure_depth is not None:
            pulumi.set(__self__, "maximum_structure_depth", maximum_structure_depth)
        if maximum_total_length is not None:
            pulumi.set(__self__, "maximum_total_length", maximum_total_length)
        if maximum_value_length is not None:
            pulumi.set(__self__, "maximum_value_length", maximum_value_length)
        if tolerate_parsing_warnings is not None:
            pulumi.set(__self__, "tolerate_parsing_warnings", tolerate_parsing_warnings)

    @_builtins.property
    @pulumi.getter(name="allowIntrospectionQueries")
    def allow_introspection_queries(self) -> Optional[_builtins.bool]:
        """
        Introspection queries can also be enforced to prevent attackers from using them to
        understand the API structure and potentially breach an application.
        """
        return pulumi.get(self, "allow_introspection_queries")

    @_builtins.property
    @pulumi.getter(name="maximumBatchedQueries")
    def maximum_batched_queries(self) -> Optional[_builtins.str]:
        """
        Specifies the highest number of batched queries allowed by the security policy.
        """
        return pulumi.get(self, "maximum_batched_queries")

    @_builtins.property
    @pulumi.getter(name="maximumStructureDepth")
    def maximum_structure_depth(self) -> Optional[_builtins.str]:
        """
        Specifies the greatest nesting depth found in the GraphQL structure allowed by the security policy.
        """
        return pulumi.get(self, "maximum_structure_depth")

    @_builtins.property
    @pulumi.getter(name="maximumTotalLength")
    def maximum_total_length(self) -> Optional[_builtins.str]:
        """
        Specifies the longest length, in bytes, allowed by the security policy of the request payload, or parameter value, where the GraphQL data was found.
        """
        return pulumi.get(self, "maximum_total_length")

    @_builtins.property
    @pulumi.getter(name="maximumValueLength")
    def maximum_value_length(self) -> Optional[_builtins.str]:
        """
        Specifies the longest length (in bytes) of the longest GraphQL element value in the document allowed by the security policy.
        """
        return pulumi.get(self, "maximum_value_length")

    @_builtins.property
    @pulumi.getter(name="tolerateParsingWarnings")
    def tolerate_parsing_warnings(self) -> Optional[_builtins.bool]:
        """
        Specifies, when checked (enabled), that the system does not report when the security enforcer encounters warnings while parsing GraphQL content. Specifies when cleared (disabled), that the security policy reports when the security enforcer encounters warnings while parsing GraphQL content. The default setting is disabled.
        """
        return pulumi.get(self, "tolerate_parsing_warnings")


@pulumi.output_type
class WafPolicyHostName(dict):
    def __init__(__self__, *,
                 name: Optional[_builtins.str] = None):
        """
        :param _builtins.str name: The unique user-given name of the policy. Policy names cannot contain spaces or special characters. Allowed characters are a-z, A-Z, 0-9, dot, dash (-), colon (:) and underscore (_).
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The unique user-given name of the policy. Policy names cannot contain spaces or special characters. Allowed characters are a-z, A-Z, 0-9, dot, dash (-), colon (:) and underscore (_).
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class WafPolicyIpException(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ipAddress":
            suggest = "ip_address"
        elif key == "ipMask":
            suggest = "ip_mask"
        elif key == "blockRequests":
            suggest = "block_requests"
        elif key == "ignoreAnomalies":
            suggest = "ignore_anomalies"
        elif key == "ignoreIpreputation":
            suggest = "ignore_ipreputation"
        elif key == "trustedbyPolicybuilder":
            suggest = "trustedby_policybuilder"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WafPolicyIpException. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WafPolicyIpException.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WafPolicyIpException.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ip_address: _builtins.str,
                 ip_mask: _builtins.str,
                 block_requests: Optional[_builtins.str] = None,
                 description: Optional[_builtins.str] = None,
                 ignore_anomalies: Optional[_builtins.bool] = None,
                 ignore_ipreputation: Optional[_builtins.bool] = None,
                 trustedby_policybuilder: Optional[_builtins.bool] = None):
        """
        :param _builtins.str ip_address: Specifies the IP address that you want the system to trust.
        :param _builtins.str ip_mask: Specifies the netmask of the exceptional IP address. This is an optional field.
        :param _builtins.str block_requests: Specifies how the system responds to blocking requests sent from this IP address. Possible options [`always`, `never`, `policy-default`].
        :param _builtins.str description: Specifies the description of the policy.
        :param _builtins.bool ignore_anomalies: Specifies when enabled that the system considers this IP address legitimate and does not take it into account when performing brute force prevention.
        :param _builtins.bool ignore_ipreputation: Specifies when enabled that the system considers this IP address legitimate even if it is found in the IP Intelligence database (a database of questionable IP addresses).
        :param _builtins.bool trustedby_policybuilder: Specifies when enabled the Policy Builder considers traffic from this IP address as being safe.
        """
        pulumi.set(__self__, "ip_address", ip_address)
        pulumi.set(__self__, "ip_mask", ip_mask)
        if block_requests is not None:
            pulumi.set(__self__, "block_requests", block_requests)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ignore_anomalies is not None:
            pulumi.set(__self__, "ignore_anomalies", ignore_anomalies)
        if ignore_ipreputation is not None:
            pulumi.set(__self__, "ignore_ipreputation", ignore_ipreputation)
        if trustedby_policybuilder is not None:
            pulumi.set(__self__, "trustedby_policybuilder", trustedby_policybuilder)

    @_builtins.property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> _builtins.str:
        """
        Specifies the IP address that you want the system to trust.
        """
        return pulumi.get(self, "ip_address")

    @_builtins.property
    @pulumi.getter(name="ipMask")
    def ip_mask(self) -> _builtins.str:
        """
        Specifies the netmask of the exceptional IP address. This is an optional field.
        """
        return pulumi.get(self, "ip_mask")

    @_builtins.property
    @pulumi.getter(name="blockRequests")
    def block_requests(self) -> Optional[_builtins.str]:
        """
        Specifies how the system responds to blocking requests sent from this IP address. Possible options [`always`, `never`, `policy-default`].
        """
        return pulumi.get(self, "block_requests")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Specifies the description of the policy.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="ignoreAnomalies")
    def ignore_anomalies(self) -> Optional[_builtins.bool]:
        """
        Specifies when enabled that the system considers this IP address legitimate and does not take it into account when performing brute force prevention.
        """
        return pulumi.get(self, "ignore_anomalies")

    @_builtins.property
    @pulumi.getter(name="ignoreIpreputation")
    def ignore_ipreputation(self) -> Optional[_builtins.bool]:
        """
        Specifies when enabled that the system considers this IP address legitimate even if it is found in the IP Intelligence database (a database of questionable IP addresses).
        """
        return pulumi.get(self, "ignore_ipreputation")

    @_builtins.property
    @pulumi.getter(name="trustedbyPolicybuilder")
    def trustedby_policybuilder(self) -> Optional[_builtins.bool]:
        """
        Specifies when enabled the Policy Builder considers traffic from this IP address as being safe.
        """
        return pulumi.get(self, "trustedby_policybuilder")


@pulumi.output_type
class WafPolicyPolicyBuilder(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "learningMode":
            suggest = "learning_mode"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WafPolicyPolicyBuilder. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WafPolicyPolicyBuilder.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WafPolicyPolicyBuilder.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 learning_mode: Optional[_builtins.str] = None):
        """
        :param _builtins.str learning_mode: learning mode setting for policy-builder, possible options: [`automatic`,`disabled`, `manual`]
        """
        if learning_mode is not None:
            pulumi.set(__self__, "learning_mode", learning_mode)

    @_builtins.property
    @pulumi.getter(name="learningMode")
    def learning_mode(self) -> Optional[_builtins.str]:
        """
        learning mode setting for policy-builder, possible options: [`automatic`,`disabled`, `manual`]
        """
        return pulumi.get(self, "learning_mode")


@pulumi.output_type
class WafPolicySignaturesSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "placesignaturesInStaging":
            suggest = "placesignatures_in_staging"
        elif key == "signatureStaging":
            suggest = "signature_staging"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WafPolicySignaturesSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WafPolicySignaturesSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WafPolicySignaturesSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 placesignatures_in_staging: Optional[_builtins.bool] = None,
                 signature_staging: Optional[_builtins.bool] = None):
        """
        :param _builtins.bool signature_staging: setting true will enforce all signature from staging
        """
        if placesignatures_in_staging is not None:
            pulumi.set(__self__, "placesignatures_in_staging", placesignatures_in_staging)
        if signature_staging is not None:
            pulumi.set(__self__, "signature_staging", signature_staging)

    @_builtins.property
    @pulumi.getter(name="placesignaturesInStaging")
    def placesignatures_in_staging(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "placesignatures_in_staging")

    @_builtins.property
    @pulumi.getter(name="signatureStaging")
    def signature_staging(self) -> Optional[_builtins.bool]:
        """
        setting true will enforce all signature from staging
        """
        return pulumi.get(self, "signature_staging")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['NetTunnelArgs', 'NetTunnel']

@pulumi.input_type
class NetTunnelArgs:
    def __init__(__self__, *,
                 local_address: pulumi.Input[_builtins.str],
                 name: pulumi.Input[_builtins.str],
                 profile: pulumi.Input[_builtins.str],
                 app_service: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_last_hop: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 idle_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 key: Optional[pulumi.Input[_builtins.int]] = None,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 mtu: Optional[pulumi.Input[_builtins.int]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_address: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_address: Optional[pulumi.Input[_builtins.str]] = None,
                 tos: Optional[pulumi.Input[_builtins.str]] = None,
                 traffic_group: Optional[pulumi.Input[_builtins.str]] = None,
                 transparent: Optional[pulumi.Input[_builtins.str]] = None,
                 use_pmtu: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a NetTunnel resource.
        :param pulumi.Input[_builtins.str] local_address: Specifies a local IP address. This option is required
        :param pulumi.Input[_builtins.str] name: Name of the tunnel
        :param pulumi.Input[_builtins.str] profile: Specifies the profile that you want to associate with the tunnel
        :param pulumi.Input[_builtins.str] app_service: The application service that the object belongs to
        :param pulumi.Input[_builtins.str] auto_last_hop: Specifies whether auto lasthop is enabled or not
        :param pulumi.Input[_builtins.str] description: User defined description
        :param pulumi.Input[_builtins.int] idle_timeout: Specifies an idle timeout for wildcard tunnels in seconds
        :param pulumi.Input[_builtins.int] key: The key field may represent different values depending on the type of the tunnel
        :param pulumi.Input[_builtins.str] mode: Specifies how the tunnel carries traffic
        :param pulumi.Input[_builtins.int] mtu: Specifies the maximum transmission unit (MTU) of the tunnel
        :param pulumi.Input[_builtins.str] partition: Displays the admin-partition within which this component resides
        :param pulumi.Input[_builtins.str] remote_address: Specifies a remote IP address
        :param pulumi.Input[_builtins.str] secondary_address: Specifies a secondary non-floating IP address when the local-address is set to a floating address
        :param pulumi.Input[_builtins.str] tos: Specifies a value for insertion into the Type of Service (ToS) octet within the IP header of the encapsulating header of transmitted packets
        :param pulumi.Input[_builtins.str] traffic_group: Specifies a traffic-group for use with the tunnel
        :param pulumi.Input[_builtins.str] transparent: Enables or disables the tunnel to be transparent
        :param pulumi.Input[_builtins.str] use_pmtu: Enables or disables the tunnel to use the PMTU (Path MTU) information provided by ICMP NeedFrag error messages
        """
        pulumi.set(__self__, "local_address", local_address)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "profile", profile)
        if app_service is not None:
            pulumi.set(__self__, "app_service", app_service)
        if auto_last_hop is not None:
            pulumi.set(__self__, "auto_last_hop", auto_last_hop)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if idle_timeout is not None:
            pulumi.set(__self__, "idle_timeout", idle_timeout)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if mtu is not None:
            pulumi.set(__self__, "mtu", mtu)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if remote_address is not None:
            pulumi.set(__self__, "remote_address", remote_address)
        if secondary_address is not None:
            pulumi.set(__self__, "secondary_address", secondary_address)
        if tos is not None:
            pulumi.set(__self__, "tos", tos)
        if traffic_group is not None:
            pulumi.set(__self__, "traffic_group", traffic_group)
        if transparent is not None:
            pulumi.set(__self__, "transparent", transparent)
        if use_pmtu is not None:
            pulumi.set(__self__, "use_pmtu", use_pmtu)

    @_builtins.property
    @pulumi.getter(name="localAddress")
    def local_address(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies a local IP address. This option is required
        """
        return pulumi.get(self, "local_address")

    @local_address.setter
    def local_address(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "local_address", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the tunnel
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def profile(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the profile that you want to associate with the tunnel
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "profile", value)

    @_builtins.property
    @pulumi.getter(name="appService")
    def app_service(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The application service that the object belongs to
        """
        return pulumi.get(self, "app_service")

    @app_service.setter
    def app_service(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_service", value)

    @_builtins.property
    @pulumi.getter(name="autoLastHop")
    def auto_last_hop(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether auto lasthop is enabled or not
        """
        return pulumi.get(self, "auto_last_hop")

    @auto_last_hop.setter
    def auto_last_hop(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auto_last_hop", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User defined description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies an idle timeout for wildcard tunnels in seconds
        """
        return pulumi.get(self, "idle_timeout")

    @idle_timeout.setter
    def idle_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "idle_timeout", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The key field may represent different values depending on the type of the tunnel
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies how the tunnel carries traffic
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mode", value)

    @_builtins.property
    @pulumi.getter
    def mtu(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the maximum transmission unit (MTU) of the tunnel
        """
        return pulumi.get(self, "mtu")

    @mtu.setter
    def mtu(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mtu", value)

    @_builtins.property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Displays the admin-partition within which this component resides
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "partition", value)

    @_builtins.property
    @pulumi.getter(name="remoteAddress")
    def remote_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a remote IP address
        """
        return pulumi.get(self, "remote_address")

    @remote_address.setter
    def remote_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "remote_address", value)

    @_builtins.property
    @pulumi.getter(name="secondaryAddress")
    def secondary_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a secondary non-floating IP address when the local-address is set to a floating address
        """
        return pulumi.get(self, "secondary_address")

    @secondary_address.setter
    def secondary_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secondary_address", value)

    @_builtins.property
    @pulumi.getter
    def tos(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a value for insertion into the Type of Service (ToS) octet within the IP header of the encapsulating header of transmitted packets
        """
        return pulumi.get(self, "tos")

    @tos.setter
    def tos(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tos", value)

    @_builtins.property
    @pulumi.getter(name="trafficGroup")
    def traffic_group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a traffic-group for use with the tunnel
        """
        return pulumi.get(self, "traffic_group")

    @traffic_group.setter
    def traffic_group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "traffic_group", value)

    @_builtins.property
    @pulumi.getter
    def transparent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables or disables the tunnel to be transparent
        """
        return pulumi.get(self, "transparent")

    @transparent.setter
    def transparent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "transparent", value)

    @_builtins.property
    @pulumi.getter(name="usePmtu")
    def use_pmtu(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables or disables the tunnel to use the PMTU (Path MTU) information provided by ICMP NeedFrag error messages
        """
        return pulumi.get(self, "use_pmtu")

    @use_pmtu.setter
    def use_pmtu(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "use_pmtu", value)


@pulumi.input_type
class _NetTunnelState:
    def __init__(__self__, *,
                 app_service: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_last_hop: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 idle_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 key: Optional[pulumi.Input[_builtins.int]] = None,
                 local_address: Optional[pulumi.Input[_builtins.str]] = None,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 mtu: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_address: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_address: Optional[pulumi.Input[_builtins.str]] = None,
                 tos: Optional[pulumi.Input[_builtins.str]] = None,
                 traffic_group: Optional[pulumi.Input[_builtins.str]] = None,
                 transparent: Optional[pulumi.Input[_builtins.str]] = None,
                 use_pmtu: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering NetTunnel resources.
        :param pulumi.Input[_builtins.str] app_service: The application service that the object belongs to
        :param pulumi.Input[_builtins.str] auto_last_hop: Specifies whether auto lasthop is enabled or not
        :param pulumi.Input[_builtins.str] description: User defined description
        :param pulumi.Input[_builtins.int] idle_timeout: Specifies an idle timeout for wildcard tunnels in seconds
        :param pulumi.Input[_builtins.int] key: The key field may represent different values depending on the type of the tunnel
        :param pulumi.Input[_builtins.str] local_address: Specifies a local IP address. This option is required
        :param pulumi.Input[_builtins.str] mode: Specifies how the tunnel carries traffic
        :param pulumi.Input[_builtins.int] mtu: Specifies the maximum transmission unit (MTU) of the tunnel
        :param pulumi.Input[_builtins.str] name: Name of the tunnel
        :param pulumi.Input[_builtins.str] partition: Displays the admin-partition within which this component resides
        :param pulumi.Input[_builtins.str] profile: Specifies the profile that you want to associate with the tunnel
        :param pulumi.Input[_builtins.str] remote_address: Specifies a remote IP address
        :param pulumi.Input[_builtins.str] secondary_address: Specifies a secondary non-floating IP address when the local-address is set to a floating address
        :param pulumi.Input[_builtins.str] tos: Specifies a value for insertion into the Type of Service (ToS) octet within the IP header of the encapsulating header of transmitted packets
        :param pulumi.Input[_builtins.str] traffic_group: Specifies a traffic-group for use with the tunnel
        :param pulumi.Input[_builtins.str] transparent: Enables or disables the tunnel to be transparent
        :param pulumi.Input[_builtins.str] use_pmtu: Enables or disables the tunnel to use the PMTU (Path MTU) information provided by ICMP NeedFrag error messages
        """
        if app_service is not None:
            pulumi.set(__self__, "app_service", app_service)
        if auto_last_hop is not None:
            pulumi.set(__self__, "auto_last_hop", auto_last_hop)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if idle_timeout is not None:
            pulumi.set(__self__, "idle_timeout", idle_timeout)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if local_address is not None:
            pulumi.set(__self__, "local_address", local_address)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if mtu is not None:
            pulumi.set(__self__, "mtu", mtu)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)
        if remote_address is not None:
            pulumi.set(__self__, "remote_address", remote_address)
        if secondary_address is not None:
            pulumi.set(__self__, "secondary_address", secondary_address)
        if tos is not None:
            pulumi.set(__self__, "tos", tos)
        if traffic_group is not None:
            pulumi.set(__self__, "traffic_group", traffic_group)
        if transparent is not None:
            pulumi.set(__self__, "transparent", transparent)
        if use_pmtu is not None:
            pulumi.set(__self__, "use_pmtu", use_pmtu)

    @_builtins.property
    @pulumi.getter(name="appService")
    def app_service(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The application service that the object belongs to
        """
        return pulumi.get(self, "app_service")

    @app_service.setter
    def app_service(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_service", value)

    @_builtins.property
    @pulumi.getter(name="autoLastHop")
    def auto_last_hop(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether auto lasthop is enabled or not
        """
        return pulumi.get(self, "auto_last_hop")

    @auto_last_hop.setter
    def auto_last_hop(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auto_last_hop", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User defined description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies an idle timeout for wildcard tunnels in seconds
        """
        return pulumi.get(self, "idle_timeout")

    @idle_timeout.setter
    def idle_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "idle_timeout", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The key field may represent different values depending on the type of the tunnel
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="localAddress")
    def local_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a local IP address. This option is required
        """
        return pulumi.get(self, "local_address")

    @local_address.setter
    def local_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "local_address", value)

    @_builtins.property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies how the tunnel carries traffic
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mode", value)

    @_builtins.property
    @pulumi.getter
    def mtu(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the maximum transmission unit (MTU) of the tunnel
        """
        return pulumi.get(self, "mtu")

    @mtu.setter
    def mtu(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mtu", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the tunnel
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Displays the admin-partition within which this component resides
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "partition", value)

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the profile that you want to associate with the tunnel
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile", value)

    @_builtins.property
    @pulumi.getter(name="remoteAddress")
    def remote_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a remote IP address
        """
        return pulumi.get(self, "remote_address")

    @remote_address.setter
    def remote_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "remote_address", value)

    @_builtins.property
    @pulumi.getter(name="secondaryAddress")
    def secondary_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a secondary non-floating IP address when the local-address is set to a floating address
        """
        return pulumi.get(self, "secondary_address")

    @secondary_address.setter
    def secondary_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secondary_address", value)

    @_builtins.property
    @pulumi.getter
    def tos(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a value for insertion into the Type of Service (ToS) octet within the IP header of the encapsulating header of transmitted packets
        """
        return pulumi.get(self, "tos")

    @tos.setter
    def tos(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tos", value)

    @_builtins.property
    @pulumi.getter(name="trafficGroup")
    def traffic_group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a traffic-group for use with the tunnel
        """
        return pulumi.get(self, "traffic_group")

    @traffic_group.setter
    def traffic_group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "traffic_group", value)

    @_builtins.property
    @pulumi.getter
    def transparent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables or disables the tunnel to be transparent
        """
        return pulumi.get(self, "transparent")

    @transparent.setter
    def transparent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "transparent", value)

    @_builtins.property
    @pulumi.getter(name="usePmtu")
    def use_pmtu(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables or disables the tunnel to use the PMTU (Path MTU) information provided by ICMP NeedFrag error messages
        """
        return pulumi.get(self, "use_pmtu")

    @use_pmtu.setter
    def use_pmtu(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "use_pmtu", value)


@pulumi.type_token("f5bigip:index/netTunnel:NetTunnel")
class NetTunnel(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_service: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_last_hop: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 idle_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 key: Optional[pulumi.Input[_builtins.int]] = None,
                 local_address: Optional[pulumi.Input[_builtins.str]] = None,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 mtu: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_address: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_address: Optional[pulumi.Input[_builtins.str]] = None,
                 tos: Optional[pulumi.Input[_builtins.str]] = None,
                 traffic_group: Optional[pulumi.Input[_builtins.str]] = None,
                 transparent: Optional[pulumi.Input[_builtins.str]] = None,
                 use_pmtu: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `NetTunnel` Manages a tunnel configuration

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        example1 = f5bigip.NetTunnel("example1",
            name="example1",
            local_address="192.16.81.240",
            profile="/Common/dslite")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_service: The application service that the object belongs to
        :param pulumi.Input[_builtins.str] auto_last_hop: Specifies whether auto lasthop is enabled or not
        :param pulumi.Input[_builtins.str] description: User defined description
        :param pulumi.Input[_builtins.int] idle_timeout: Specifies an idle timeout for wildcard tunnels in seconds
        :param pulumi.Input[_builtins.int] key: The key field may represent different values depending on the type of the tunnel
        :param pulumi.Input[_builtins.str] local_address: Specifies a local IP address. This option is required
        :param pulumi.Input[_builtins.str] mode: Specifies how the tunnel carries traffic
        :param pulumi.Input[_builtins.int] mtu: Specifies the maximum transmission unit (MTU) of the tunnel
        :param pulumi.Input[_builtins.str] name: Name of the tunnel
        :param pulumi.Input[_builtins.str] partition: Displays the admin-partition within which this component resides
        :param pulumi.Input[_builtins.str] profile: Specifies the profile that you want to associate with the tunnel
        :param pulumi.Input[_builtins.str] remote_address: Specifies a remote IP address
        :param pulumi.Input[_builtins.str] secondary_address: Specifies a secondary non-floating IP address when the local-address is set to a floating address
        :param pulumi.Input[_builtins.str] tos: Specifies a value for insertion into the Type of Service (ToS) octet within the IP header of the encapsulating header of transmitted packets
        :param pulumi.Input[_builtins.str] traffic_group: Specifies a traffic-group for use with the tunnel
        :param pulumi.Input[_builtins.str] transparent: Enables or disables the tunnel to be transparent
        :param pulumi.Input[_builtins.str] use_pmtu: Enables or disables the tunnel to use the PMTU (Path MTU) information provided by ICMP NeedFrag error messages
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetTunnelArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `NetTunnel` Manages a tunnel configuration

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        example1 = f5bigip.NetTunnel("example1",
            name="example1",
            local_address="192.16.81.240",
            profile="/Common/dslite")
        ```

        :param str resource_name: The name of the resource.
        :param NetTunnelArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetTunnelArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_service: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_last_hop: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 idle_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 key: Optional[pulumi.Input[_builtins.int]] = None,
                 local_address: Optional[pulumi.Input[_builtins.str]] = None,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 mtu: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_address: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_address: Optional[pulumi.Input[_builtins.str]] = None,
                 tos: Optional[pulumi.Input[_builtins.str]] = None,
                 traffic_group: Optional[pulumi.Input[_builtins.str]] = None,
                 transparent: Optional[pulumi.Input[_builtins.str]] = None,
                 use_pmtu: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetTunnelArgs.__new__(NetTunnelArgs)

            __props__.__dict__["app_service"] = app_service
            __props__.__dict__["auto_last_hop"] = auto_last_hop
            __props__.__dict__["description"] = description
            __props__.__dict__["idle_timeout"] = idle_timeout
            __props__.__dict__["key"] = key
            if local_address is None and not opts.urn:
                raise TypeError("Missing required property 'local_address'")
            __props__.__dict__["local_address"] = local_address
            __props__.__dict__["mode"] = mode
            __props__.__dict__["mtu"] = mtu
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["partition"] = partition
            if profile is None and not opts.urn:
                raise TypeError("Missing required property 'profile'")
            __props__.__dict__["profile"] = profile
            __props__.__dict__["remote_address"] = remote_address
            __props__.__dict__["secondary_address"] = secondary_address
            __props__.__dict__["tos"] = tos
            __props__.__dict__["traffic_group"] = traffic_group
            __props__.__dict__["transparent"] = transparent
            __props__.__dict__["use_pmtu"] = use_pmtu
        super(NetTunnel, __self__).__init__(
            'f5bigip:index/netTunnel:NetTunnel',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_service: Optional[pulumi.Input[_builtins.str]] = None,
            auto_last_hop: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            idle_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            key: Optional[pulumi.Input[_builtins.int]] = None,
            local_address: Optional[pulumi.Input[_builtins.str]] = None,
            mode: Optional[pulumi.Input[_builtins.str]] = None,
            mtu: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            partition: Optional[pulumi.Input[_builtins.str]] = None,
            profile: Optional[pulumi.Input[_builtins.str]] = None,
            remote_address: Optional[pulumi.Input[_builtins.str]] = None,
            secondary_address: Optional[pulumi.Input[_builtins.str]] = None,
            tos: Optional[pulumi.Input[_builtins.str]] = None,
            traffic_group: Optional[pulumi.Input[_builtins.str]] = None,
            transparent: Optional[pulumi.Input[_builtins.str]] = None,
            use_pmtu: Optional[pulumi.Input[_builtins.str]] = None) -> 'NetTunnel':
        """
        Get an existing NetTunnel resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_service: The application service that the object belongs to
        :param pulumi.Input[_builtins.str] auto_last_hop: Specifies whether auto lasthop is enabled or not
        :param pulumi.Input[_builtins.str] description: User defined description
        :param pulumi.Input[_builtins.int] idle_timeout: Specifies an idle timeout for wildcard tunnels in seconds
        :param pulumi.Input[_builtins.int] key: The key field may represent different values depending on the type of the tunnel
        :param pulumi.Input[_builtins.str] local_address: Specifies a local IP address. This option is required
        :param pulumi.Input[_builtins.str] mode: Specifies how the tunnel carries traffic
        :param pulumi.Input[_builtins.int] mtu: Specifies the maximum transmission unit (MTU) of the tunnel
        :param pulumi.Input[_builtins.str] name: Name of the tunnel
        :param pulumi.Input[_builtins.str] partition: Displays the admin-partition within which this component resides
        :param pulumi.Input[_builtins.str] profile: Specifies the profile that you want to associate with the tunnel
        :param pulumi.Input[_builtins.str] remote_address: Specifies a remote IP address
        :param pulumi.Input[_builtins.str] secondary_address: Specifies a secondary non-floating IP address when the local-address is set to a floating address
        :param pulumi.Input[_builtins.str] tos: Specifies a value for insertion into the Type of Service (ToS) octet within the IP header of the encapsulating header of transmitted packets
        :param pulumi.Input[_builtins.str] traffic_group: Specifies a traffic-group for use with the tunnel
        :param pulumi.Input[_builtins.str] transparent: Enables or disables the tunnel to be transparent
        :param pulumi.Input[_builtins.str] use_pmtu: Enables or disables the tunnel to use the PMTU (Path MTU) information provided by ICMP NeedFrag error messages
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetTunnelState.__new__(_NetTunnelState)

        __props__.__dict__["app_service"] = app_service
        __props__.__dict__["auto_last_hop"] = auto_last_hop
        __props__.__dict__["description"] = description
        __props__.__dict__["idle_timeout"] = idle_timeout
        __props__.__dict__["key"] = key
        __props__.__dict__["local_address"] = local_address
        __props__.__dict__["mode"] = mode
        __props__.__dict__["mtu"] = mtu
        __props__.__dict__["name"] = name
        __props__.__dict__["partition"] = partition
        __props__.__dict__["profile"] = profile
        __props__.__dict__["remote_address"] = remote_address
        __props__.__dict__["secondary_address"] = secondary_address
        __props__.__dict__["tos"] = tos
        __props__.__dict__["traffic_group"] = traffic_group
        __props__.__dict__["transparent"] = transparent
        __props__.__dict__["use_pmtu"] = use_pmtu
        return NetTunnel(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appService")
    def app_service(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The application service that the object belongs to
        """
        return pulumi.get(self, "app_service")

    @_builtins.property
    @pulumi.getter(name="autoLastHop")
    def auto_last_hop(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies whether auto lasthop is enabled or not
        """
        return pulumi.get(self, "auto_last_hop")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        User defined description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Specifies an idle timeout for wildcard tunnels in seconds
        """
        return pulumi.get(self, "idle_timeout")

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The key field may represent different values depending on the type of the tunnel
        """
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter(name="localAddress")
    def local_address(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies a local IP address. This option is required
        """
        return pulumi.get(self, "local_address")

    @_builtins.property
    @pulumi.getter
    def mode(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies how the tunnel carries traffic
        """
        return pulumi.get(self, "mode")

    @_builtins.property
    @pulumi.getter
    def mtu(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Specifies the maximum transmission unit (MTU) of the tunnel
        """
        return pulumi.get(self, "mtu")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the tunnel
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def partition(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Displays the admin-partition within which this component resides
        """
        return pulumi.get(self, "partition")

    @_builtins.property
    @pulumi.getter
    def profile(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the profile that you want to associate with the tunnel
        """
        return pulumi.get(self, "profile")

    @_builtins.property
    @pulumi.getter(name="remoteAddress")
    def remote_address(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies a remote IP address
        """
        return pulumi.get(self, "remote_address")

    @_builtins.property
    @pulumi.getter(name="secondaryAddress")
    def secondary_address(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies a secondary non-floating IP address when the local-address is set to a floating address
        """
        return pulumi.get(self, "secondary_address")

    @_builtins.property
    @pulumi.getter
    def tos(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies a value for insertion into the Type of Service (ToS) octet within the IP header of the encapsulating header of transmitted packets
        """
        return pulumi.get(self, "tos")

    @_builtins.property
    @pulumi.getter(name="trafficGroup")
    def traffic_group(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies a traffic-group for use with the tunnel
        """
        return pulumi.get(self, "traffic_group")

    @_builtins.property
    @pulumi.getter
    def transparent(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Enables or disables the tunnel to be transparent
        """
        return pulumi.get(self, "transparent")

    @_builtins.property
    @pulumi.getter(name="usePmtu")
    def use_pmtu(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Enables or disables the tunnel to use the PMTU (Path MTU) information provided by ICMP NeedFrag error messages
        """
        return pulumi.get(self, "use_pmtu")

